<?php

namespace Drupal\wvn_api\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\wvn_api\Services\WvnSync;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Url;
use Drupal\Core\Messenger\Messenger;

/**
 * Manual import wvn jobs.
 *
 * @package Drupal\wvn_api\Form
 */
class WvnManualRunForm extends FormBase {

  /**
   * Wvn Sync.
   *
   * @var \Drupal\wvn_api\Services\WvnSync
   */
  protected $wvnSync;

  /**
   * The configuration of this module.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * The messenger service.
   *
   * @var \Drupal\Core\Messenger\Messenger
   */
  protected $messenger;

  /**
   * Class constructor.
   *
   * @param \Drupal\wvn_api\Services\WvnSync $wvn_sync
   *   The wvn sync service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Config factory.
   * @param \Drupal\Core\Messenger\Messenger $messenger
   *   Config factory.
   */
  public function __construct(WvnSync $wvn_sync, ConfigFactoryInterface $config_factory, Messenger $messenger) {
    $this->wvnSync = $wvn_sync;
    $this->config = $config_factory->get('wvn_api.settings');
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('wvn_api.sync'),
      $container->get('config.factory'),
      $container->get('messenger')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'wvn_api_admin_manual';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $endpoint = $this->config->get('endpoint');
    if (empty($endpoint)) {
      $form['warning'] = [
        '#type' => 'html_tag',
        '#tag' => 'div',
        '#attributes' => ['class' => ['messages messages--warning']],
        '#value' => $this->t('Please <a href="@url">configure</a> the module first.', ['@url' => Url::fromRoute('wvn_api.settings')->toString()]),
      ];
    }
    else {
      $form['help'] = [
        '#type' => 'markup',
        '#markup' => $this->t('Submitting this form will sync the wvn api items manually.'),
      ];
      $form['actions']['#type'] = 'actions';
      $form['actions']['submit'] = [
        '#type' => 'submit',
        '#value' => $this->t('Sync'),
        '#button_type' => 'primary',
      ];
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $processed = $this->wvnSync->updateJobs();
    $this->messenger()->addMessage($this->t('Processed @count items', ['@count' => $processed]));
  }

}
