<?php

namespace Drupal\wvn_api\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings form.
 *
 * @package Drupal\wvn_api\Form
 */
class WvnSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'wvn_api_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'wvn_api.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('wvn_api.settings');
    $form['endpoint'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Endpoint'),
      '#default_value' => $config->get('endpoint'),
      '#required' => TRUE,
    ];
    $form['username'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Username'),
      '#default_value' => $config->get('username'),
      '#required' => TRUE,
    ];
    $form['password'] = [
      '#type' => 'password',
      '#title' => $this->t('Password'),
    ];
    $form['selector'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Selector for organization'),
      '#default_value' => $config->get('selector'),
    ];
    $form['allowed_status'] = [
      '#type' => 'select',
      '#options' => [
        // @todo Make this configurable.
        'HPK' => $this->t('HPK'),
        'VWNW' => $this->t('VWNW'),
        'HPK/VWNW' => $this->t('HPK/VWNW'),
        'Intern' => $this->t('Intern'),
        'Interdepartementaal' => $this->t('Interdepartementaal'),
        'Extern' => $this->t('Extern'),
      ],
      '#multiple' => TRUE,
      '#title' => $this->t('Allowed status'),
      '#description' => $this->t('Only import items with this status'),
      '#default_value' => $config->get('allowed_status'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $config_factory = $this->configFactory->getEditable('wvn_api.settings');
    $config_factory->set('endpoint', $form_state->getValue('endpoint'));
    $config_factory->set('username', $form_state->getValue('username'));
    if (!empty($form_state->getValue('password'))) {
      $config_factory->set('password', $form_state->getValue('password'));
    }
    $config_factory->set('selector', $form_state->getValue('selector'));
    $config_factory->set('allowed_status', $form_state->getValue('allowed_status'));

    $config_factory->save();
    parent::submitForm($form, $form_state);
  }

}
